@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.075'; 
+our $VERSION = '1.076'; 
 $VERSION = eval $VERSION;
 
 use strict;
@@ -472,9 +472,12 @@ sub info {
 }
 
 sub get_permalink {
-	# commentid is short id
-	# post_fullname is because we need to get the post to get its permalink
+	# This still makes an extra request
 	my ($self, $commentid, $post_fullname) = @_;
+
+	if (substr ($commentid, 0, 3) eq "t1_") { $commentid = substr $commentid, 3; } 
+	if (substr ($post_fullname, 0, 3) ne "t3_") { $post_fullname = "t3_" . $post_fullname; } 
+
 	my $info = $self->info($post_fullname);
 	return sprintf "%s%s%s", $LINK_URL, $info->{permalink}, $commentid;
 }
